@@ -73,15 +73,25 @@ class SubscriptionManager:
         await self._close_websocket()
 
         _LOGGER.debug("Starting")
-        self.websocket = await websockets.connect(
-            self._url,
-            subprotocols=["graphql-subscriptions"],
-            extra_headers={"User-Agent": self._user_agent},
-        )
+        try:
+            self.websocket = await asyncio.wait_for(
+                websockets.connect(
+                    self._url,
+                    subprotocols=["graphql-subscriptions"],
+                    extra_headers={"User-Agent": self._user_agent},
+                ),
+                timeout=30,
+            )
+        except Exception:  # pylint: disable=broad-except
+            _LOGGER.debug("Failed to connect. Reconnecting... ", exc_info=True)
+            self._state = STATE_STOPPED
+            self.retry()
+            return
+
         self._state = STATE_RUNNING
         _LOGGER.debug("Running")
         await self.websocket.send(
-            json.dumps({"type": "init", "payload": self._init_payload}),
+            json.dumps({"type": "init", "payload": self._init_payload})
         )
 
         try:
